"""
Image MCP Server

A Model Context Protocol server for image understanding using
Alibaba Cloud's Qwen3-VL-Plus model.
"""

__version__ = "0.1.3"
__author__ = "Image MCP Server Contributors"
__email__ = "maintainers@example.com"
__license__ = "MIT"
__description__ = "MCP server for image understanding using Alibaba Cloud's Qwen3-VL-Plus model"
__url__ = "https://github.com/your-repo/image-mcp-server"

# Import server only when needed to avoid circular imports
# from .server import ImageMCPServer

__all__ = ["__version__", "__author__", "__email__", "__license__", "__description__", "__url__"]